# Changelog

All notable changes to **acatome-meta** will be documented in this file.

Format follows [Keep a Changelog](https://keepachangelog.com/).

## [0.1.0] — 2026-03-11

### Added

- Initial release.
